/* This is a GENERATED file. */
/* Generated data (by glib-mkenums) */

#include "gwydgettypes.h"

#include "./gwydgetenums.h"

GType
gwy_axis_scale_format_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_AXIS_SCALE_FORMAT_AUTO, "GWY_AXIS_SCALE_FORMAT_AUTO", "auto" },
            { GWY_AXIS_SCALE_FORMAT_EXP, "GWY_AXIS_SCALE_FORMAT_EXP", "exp" },
            { GWY_AXIS_SCALE_FORMAT_INT, "GWY_AXIS_SCALE_FORMAT_INT", "int" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyAxisScaleFormat", values);
    }
    return etype;
}

GType
gwy_3d_movement_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_3D_MOVEMENT_NONE, "GWY_3D_MOVEMENT_NONE", "none" },
            { GWY_3D_MOVEMENT_ROTATION, "GWY_3D_MOVEMENT_ROTATION", "rotation" },
            { GWY_3D_MOVEMENT_SCALE, "GWY_3D_MOVEMENT_SCALE", "scale" },
            { GWY_3D_MOVEMENT_DEFORMATION, "GWY_3D_MOVEMENT_DEFORMATION", "deformation" },
            { GWY_3D_MOVEMENT_LIGHT, "GWY_3D_MOVEMENT_LIGHT", "light" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("Gwy3DMovement", values);
    }
    return etype;
}

GType
gwy_3d_projection_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_3D_PROJECTION_ORTHOGRAPHIC, "GWY_3D_PROJECTION_ORTHOGRAPHIC", "orthographic" },
            { GWY_3D_PROJECTION_PERSPECTIVE, "GWY_3D_PROJECTION_PERSPECTIVE", "perspective" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("Gwy3DProjection", values);
    }
    return etype;
}

GType
gwy_3d_visualization_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_3D_VISUALIZATION_GRADIENT, "GWY_3D_VISUALIZATION_GRADIENT", "gradient" },
            { GWY_3D_VISUALIZATION_LIGHTING, "GWY_3D_VISUALIZATION_LIGHTING", "lighting" },
            { GWY_3D_VISUALIZATION_OVERLAY, "GWY_3D_VISUALIZATION_OVERLAY", "overlay" },
            { GWY_3D_VISUALIZATION_OVERLAY_NO_LIGHT, "GWY_3D_VISUALIZATION_OVERLAY_NO_LIGHT", "overlay-no-light" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("Gwy3DVisualization", values);
    }
    return etype;
}

GType
gwy_3d_view_label_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_3D_VIEW_LABEL_X, "GWY_3D_VIEW_LABEL_X", "label-x" },
            { GWY_3D_VIEW_LABEL_Y, "GWY_3D_VIEW_LABEL_Y", "label-y" },
            { GWY_3D_VIEW_LABEL_MIN, "GWY_3D_VIEW_LABEL_MIN", "label-min" },
            { GWY_3D_VIEW_LABEL_MAX, "GWY_3D_VIEW_LABEL_MAX", "label-max" },
            { GWY_3D_VIEW_NLABELS, "GWY_3D_VIEW_NLABELS", "nlabels" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("Gwy3DViewLabel", values);
    }
    return etype;
}

GType
gwy_units_placement_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_UNITS_PLACEMENT_NONE, "GWY_UNITS_PLACEMENT_NONE", "none" },
            { GWY_UNITS_PLACEMENT_AT_ZERO, "GWY_UNITS_PLACEMENT_AT_ZERO", "at-zero" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyUnitsPlacement", values);
    }
    return etype;
}

GType
gwy_hscale_style_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_HSCALE_DEFAULT, "GWY_HSCALE_DEFAULT", "default" },
            { GWY_HSCALE_LOG, "GWY_HSCALE_LOG", "log" },
            { GWY_HSCALE_SQRT, "GWY_HSCALE_SQRT", "sqrt" },
            { GWY_HSCALE_LINEAR, "GWY_HSCALE_LINEAR", "linear" },
            { GWY_HSCALE_NO_SCALE, "GWY_HSCALE_NO_SCALE", "no-scale" },
            { GWY_HSCALE_WIDGET, "GWY_HSCALE_WIDGET", "widget" },
            { GWY_HSCALE_WIDGET_NO_EXPAND, "GWY_HSCALE_WIDGET_NO_EXPAND", "widget-no-expand" },
            { GWY_HSCALE_CHECK, "GWY_HSCALE_CHECK", "check" },
            { GWY_HSCALE_SNAP, "GWY_HSCALE_SNAP", "snap" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyHScaleStyle", values);
    }
    return etype;
}

GType
gwy_graph_status_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_GRAPH_STATUS_PLAIN, "GWY_GRAPH_STATUS_PLAIN", "plain" },
            { GWY_GRAPH_STATUS_XSEL, "GWY_GRAPH_STATUS_XSEL", "xsel" },
            { GWY_GRAPH_STATUS_YSEL, "GWY_GRAPH_STATUS_YSEL", "ysel" },
            { GWY_GRAPH_STATUS_POINTS, "GWY_GRAPH_STATUS_POINTS", "points" },
            { GWY_GRAPH_STATUS_ZOOM, "GWY_GRAPH_STATUS_ZOOM", "zoom" },
            { GWY_GRAPH_STATUS_XLINES, "GWY_GRAPH_STATUS_XLINES", "xlines" },
            { GWY_GRAPH_STATUS_YLINES, "GWY_GRAPH_STATUS_YLINES", "ylines" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyGraphStatusType", values);
    }
    return etype;
}

GType
gwy_graph_grid_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_GRAPH_GRID_NONE, "GWY_GRAPH_GRID_NONE", "none" },
            { GWY_GRAPH_GRID_AUTO, "GWY_GRAPH_GRID_AUTO", "auto" },
            { GWY_GRAPH_GRID_USER, "GWY_GRAPH_GRID_USER", "user" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyGraphGridType", values);
    }
    return etype;
}

GType
gwy_graph_point_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_GRAPH_POINT_SQUARE, "GWY_GRAPH_POINT_SQUARE", "square" },
            { GWY_GRAPH_POINT_CROSS, "GWY_GRAPH_POINT_CROSS", "cross" },
            { GWY_GRAPH_POINT_CIRCLE, "GWY_GRAPH_POINT_CIRCLE", "circle" },
            { GWY_GRAPH_POINT_STAR, "GWY_GRAPH_POINT_STAR", "star" },
            { GWY_GRAPH_POINT_TIMES, "GWY_GRAPH_POINT_TIMES", "times" },
            { GWY_GRAPH_POINT_TRIANGLE_UP, "GWY_GRAPH_POINT_TRIANGLE_UP", "triangle-up" },
            { GWY_GRAPH_POINT_TRIANGLE_DOWN, "GWY_GRAPH_POINT_TRIANGLE_DOWN", "triangle-down" },
            { GWY_GRAPH_POINT_DIAMOND, "GWY_GRAPH_POINT_DIAMOND", "diamond" },
            { GWY_GRAPH_POINT_FILLED_SQUARE, "GWY_GRAPH_POINT_FILLED_SQUARE", "filled-square" },
            { GWY_GRAPH_POINT_DISC, "GWY_GRAPH_POINT_DISC", "disc" },
            { GWY_GRAPH_POINT_FILLED_CIRCLE, "GWY_GRAPH_POINT_FILLED_CIRCLE", "filled-circle" },
            { GWY_GRAPH_POINT_FILLED_TRIANGLE_UP, "GWY_GRAPH_POINT_FILLED_TRIANGLE_UP", "filled-triangle-up" },
            { GWY_GRAPH_POINT_FILLED_TRIANGLE_DOWN, "GWY_GRAPH_POINT_FILLED_TRIANGLE_DOWN", "filled-triangle-down" },
            { GWY_GRAPH_POINT_FILLED_DIAMOND, "GWY_GRAPH_POINT_FILLED_DIAMOND", "filled-diamond" },
            { GWY_GRAPH_POINT_TRIANGLE_LEFT, "GWY_GRAPH_POINT_TRIANGLE_LEFT", "triangle-left" },
            { GWY_GRAPH_POINT_FILLED_TRIANGLE_LEFT, "GWY_GRAPH_POINT_FILLED_TRIANGLE_LEFT", "filled-triangle-left" },
            { GWY_GRAPH_POINT_TRIANGLE_RIGHT, "GWY_GRAPH_POINT_TRIANGLE_RIGHT", "triangle-right" },
            { GWY_GRAPH_POINT_FILLED_TRIANGLE_RIGHT, "GWY_GRAPH_POINT_FILLED_TRIANGLE_RIGHT", "filled-triangle-right" },
            { GWY_GRAPH_POINT_ASTERISK, "GWY_GRAPH_POINT_ASTERISK", "asterisk" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyGraphPointType", values);
    }
    return etype;
}

GType
gwy_graph_curve_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_GRAPH_CURVE_HIDDEN, "GWY_GRAPH_CURVE_HIDDEN", "hidden" },
            { GWY_GRAPH_CURVE_POINTS, "GWY_GRAPH_CURVE_POINTS", "points" },
            { GWY_GRAPH_CURVE_LINE, "GWY_GRAPH_CURVE_LINE", "line" },
            { GWY_GRAPH_CURVE_LINE_POINTS, "GWY_GRAPH_CURVE_LINE_POINTS", "line-points" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyGraphCurveType", values);
    }
    return etype;
}

GType
gwy_graph_label_position_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_GRAPH_LABEL_NORTHEAST, "GWY_GRAPH_LABEL_NORTHEAST", "northeast" },
            { GWY_GRAPH_LABEL_NORTHWEST, "GWY_GRAPH_LABEL_NORTHWEST", "northwest" },
            { GWY_GRAPH_LABEL_SOUTHEAST, "GWY_GRAPH_LABEL_SOUTHEAST", "southeast" },
            { GWY_GRAPH_LABEL_SOUTHWEST, "GWY_GRAPH_LABEL_SOUTHWEST", "southwest" },
            { GWY_GRAPH_LABEL_USER, "GWY_GRAPH_LABEL_USER", "user" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyGraphLabelPosition", values);
    }
    return etype;
}

GType
gwy_graph_model_export_style_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_GRAPH_MODEL_EXPORT_ASCII_PLAIN, "GWY_GRAPH_MODEL_EXPORT_ASCII_PLAIN", "plain" },
            { GWY_GRAPH_MODEL_EXPORT_ASCII_GNUPLOT, "GWY_GRAPH_MODEL_EXPORT_ASCII_GNUPLOT", "gnuplot" },
            { GWY_GRAPH_MODEL_EXPORT_ASCII_CSV, "GWY_GRAPH_MODEL_EXPORT_ASCII_CSV", "csv" },
            { GWY_GRAPH_MODEL_EXPORT_ASCII_ORIGIN, "GWY_GRAPH_MODEL_EXPORT_ASCII_ORIGIN", "origin" },
            { GWY_GRAPH_MODEL_EXPORT_ASCII_IGORPRO, "GWY_GRAPH_MODEL_EXPORT_ASCII_IGORPRO", "igorpro" },
            { GWY_GRAPH_MODEL_EXPORT_ASCII_POSIX, "GWY_GRAPH_MODEL_EXPORT_ASCII_POSIX", "posix" },
            { GWY_GRAPH_MODEL_EXPORT_ASCII_MERGED, "GWY_GRAPH_MODEL_EXPORT_ASCII_MERGED", "merged" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyGraphModelExportStyle", values);
    }
    return etype;
}

GType
gwy_layer_basic_range_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_LAYER_BASIC_RANGE_FULL, "GWY_LAYER_BASIC_RANGE_FULL", "full" },
            { GWY_LAYER_BASIC_RANGE_FIXED, "GWY_LAYER_BASIC_RANGE_FIXED", "fixed" },
            { GWY_LAYER_BASIC_RANGE_AUTO, "GWY_LAYER_BASIC_RANGE_AUTO", "auto" },
            { GWY_LAYER_BASIC_RANGE_ADAPT, "GWY_LAYER_BASIC_RANGE_ADAPT", "adapt" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyLayerBasicRangeType", values);
    }
    return etype;
}

GType
gwy_curve_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_CURVE_TYPE_LINEAR, "GWY_CURVE_TYPE_LINEAR", "linear" },
            { GWY_CURVE_TYPE_SPLINE, "GWY_CURVE_TYPE_SPLINE", "spline" },
            { GWY_CURVE_TYPE_FREE, "GWY_CURVE_TYPE_FREE", "free" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyCurveType", values);
    }
    return etype;
}

GType
gwy_curve_channel_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_CURVE_CHANNEL_RED, "GWY_CURVE_CHANNEL_RED", "red" },
            { GWY_CURVE_CHANNEL_GREEN, "GWY_CURVE_CHANNEL_GREEN", "green" },
            { GWY_CURVE_CHANNEL_BLUE, "GWY_CURVE_CHANNEL_BLUE", "blue" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyCurveChannel", values);
    }
    return etype;
}

GType
gwy_marker_operation_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_MARKER_OPERATION_MOVE, "GWY_MARKER_OPERATION_MOVE", "move" },
            { GWY_MARKER_OPERATION_ADD, "GWY_MARKER_OPERATION_ADD", "add" },
            { GWY_MARKER_OPERATION_REMOVE, "GWY_MARKER_OPERATION_REMOVE", "remove" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyMarkerOperationType", values);
    }
    return etype;
}

GType
gwy_data_view_layer_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_DATA_VIEW_LAYER_BASE, "GWY_DATA_VIEW_LAYER_BASE", "base" },
            { GWY_DATA_VIEW_LAYER_ALPHA, "GWY_DATA_VIEW_LAYER_ALPHA", "alpha" },
            { GWY_DATA_VIEW_LAYER_TOP, "GWY_DATA_VIEW_LAYER_TOP", "top" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyDataViewLayerType", values);
    }
    return etype;
}

GType
gwy_ticks_style_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_TICKS_STYLE_NONE, "GWY_TICKS_STYLE_NONE", "none" },
            { GWY_TICKS_STYLE_CENTER, "GWY_TICKS_STYLE_CENTER", "center" },
            { GWY_TICKS_STYLE_AUTO, "GWY_TICKS_STYLE_AUTO", "auto" },
            { GWY_TICKS_STYLE_UNLABELED, "GWY_TICKS_STYLE_UNLABELED", "unlabeled" },
            { GWY_TICKS_STYLE_UNLABELLED, "GWY_TICKS_STYLE_UNLABELLED", "unlabelled" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyTicksStyle", values);
    }
    return etype;
}

#include "./gwyadjustbar.h"

GType
gwy_scale_mapping_type_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_SCALE_MAPPING_LINEAR, "GWY_SCALE_MAPPING_LINEAR", "linear" },
            { GWY_SCALE_MAPPING_SQRT, "GWY_SCALE_MAPPING_SQRT", "sqrt" },
            { GWY_SCALE_MAPPING_LOG, "GWY_SCALE_MAPPING_LOG", "log" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyScaleMappingType", values);
    }
    return etype;
}

#include "./gwygrainvaluemenu.h"

GType
gwy_grain_value_store_column_get_type(void)
{
    static GType etype = 0;

    if (etype == 0) {
        static const GEnumValue values[] = {
            { GWY_GRAIN_VALUE_STORE_COLUMN_ITEM, "GWY_GRAIN_VALUE_STORE_COLUMN_ITEM", "item" },
            { GWY_GRAIN_VALUE_STORE_COLUMN_GROUP, "GWY_GRAIN_VALUE_STORE_COLUMN_GROUP", "group" },
            { GWY_GRAIN_VALUE_STORE_COLUMN_ENABLED, "GWY_GRAIN_VALUE_STORE_COLUMN_ENABLED", "enabled" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static("GwyGrainValueStoreColumn", values);
    }
    return etype;
}


/* Generated data ends here */

